<div align="Center">

# frizzle 

Combine spectra by forward modeling [(Hogg & Casey, 20xx)](https://arxiv.org/abs/2403.11011).

[![Test Status](https://github.com/andycasey/frizzle/actions/workflows/ci.yml/badge.svg)](https://github.com/andycasey/frizzle/actions/workflows/ci.yml)
[![Coverage Status](https://coveralls.io/repos/github/andycasey/frizzle/badge.svg?branch=main&service=github)](https://coveralls.io/github/andycasey/frizzle?branch=main)

</div>

# Install

```
uv add frizzle
```

# Getting Started Guide

[todo]

# Authors
- **David W Hogg** (NYU) (MPIA) (Flatiron)
- **Andy Casey** (Monash) (Flatiron)


With contributions from:
- **Matt Daunt** (NYU);
- **Thomas Hilder** (Monash);
- **Adrian Price-Whelan** (Flatiron);
- the **Astronomical Data Group** at the Flatiron Institute; and 
- the **Inference Group** at Monash University.

